@@ -2,9 +2,7 @@ from PySide2.QtWidgets import QApplication
 
 __title__ = "Source editor"
 __description__ = "A plugin to display selections"
-__long_description__ = QApplication.instance().translate(
-    "source_editor",
-    """
+__long_description__ = """
 <p>It is a plugin allowing to work on a subset of variants.<br>
 A subset of variants is called selection or source.
 </p>
@@ -30,7 +28,6 @@ whose intervals will be used to filter the variants of the starting selection;</
 <em>Filters Editor</em> plugin;</li>
 <li>Via custom filters, from the <em>Filters Editor</em> plugin.</li>
 </ul>
-""",
-)
+"""
 __author__ = "Sacha schutz"
 __version__ = "1.0.0"
