@@ -2,12 +2,9 @@ from PySide2.QtWidgets import QApplication
 
 __title__ = "Statistics"
 __description__ = "A plugin to display statistics for the selected "
-__long_description__ = QApplication.instance().translate(
-    "stats_widget",
-    """
+__long_description__ = """
 <p>This plugins shows general statistics about a selected column.</p>
 It can be used to evaluate
-""",
-)
+"""
 __author__ = "Charles Monod-Broca"
 __version__ = "1.0.0"
\ No newline at end of file
