@@ -10,4 +10,4 @@ from .file_edit import FileEdit
 
 from .field_editor_widget import FieldsEditorWidget
 
-from .searchable_table_widget import SearchableTableWidget
+from .searchable_table_widget import LoadingTableView, SearchableTableWidget
